select distinct rowner
from   dba_refresh
order by rowner
